==> pf4-component-mapper-3.4.1.tgz: package/esm/wizard/wizard-components/step-buttons.js <==
import _extends from "@babel/runtime/helpers/extends";
import React from 'react';
import PropTypes from 'prop-types';
import { Button } from "@patternfly/react-core/dist/esm/components/Button/Button.js";
import selectNext from '@data-driven-forms/common/wizard/select-next';
import FormSpy from "@data-driven-forms/react-form-renderer/form-spy";

var NextButton = function NextButton(_ref) {
  var nextStep = _ref.nextStep,
      valid = _ref.valid,
      handleNext = _ref.handleNext,
      nextLabel = _ref.nextLabel,
      getState = _ref.getState,
      handleSubmit = _ref.handleSubmit,
      submitLabel = _ref.submitLabel;
  return /*#__PURE__*/React.createElement(Button, {
    variant: "primary",
    type: "button",
    isDisabled: !valid || getState().validating,
    onClick: function onClick() {
      return nextStep ? handleNext(selectNext(nextStep, getState)) : handleSubmit();
    }
  }, nextStep ? nextLabel : submitLabel);
};

NextButton.propTypes = {
  nextStep: PropTypes.oneOfType([PropTypes.string, PropTypes.func, PropTypes.object]),
  handleSubmit: PropTypes.func.isRequired,
  submitLabel: PropTypes.node.isRequired,
  valid: PropTypes.bool,
  handleNext: PropTypes.func.isRequired,
  nextLabel: PropTypes.node.isRequired,
  getState: PropTypes.func.isRequired
};

var WizardStepButtons = function WizardStepButtons(_ref2) {
  var Buttons = _ref2.buttons,
      disableBack = _ref2.disableBack,
      handlePrev = _ref2.handlePrev,
      nextStep = _ref2.nextStep,
      handleNext = _ref2.handleNext,
      buttonsClassName = _ref2.buttonsClassName,
      _ref2$buttonLabels = _ref2.buttonLabels,
      cancel = _ref2$buttonLabels.cancel,
      submit = _ref2$buttonLabels.submit,
      back = _ref2$buttonLabels.back,
      next = _ref2$buttonLabels.next,
      formOptions = _ref2.formOptions;
  return /*#__PURE__*/React.createElement("footer", {
    className: "pf-c-wizard__footer ".concat(buttonsClassName ? buttonsClassName : '')
  }, Buttons ? /*#__PURE__*/React.createElement(Buttons, {
    disableBack: disableBack,
    handlePrev: handlePrev,
    nextStep: nextStep,
    handleNext: handleNext,
    buttonsClassName: buttonsClassName,
    buttonLabels: {
      cancel: cancel,
      submit: submit,
      back: back,
      next: next
    },
    renderNextButton: function renderNextButton(args) {
      return /*#__PURE__*/React.createElement(NextButton, _extends({}, formOptions, {
        handleNext: handleNext,
        nextStep: nextStep,
        nextLabel: next,
        submitLabel: submit
      }, args));
    },
    selectNext: selectNext
  }) : /*#__PURE__*/React.createElement(FormSpy, null, function () {
    return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(NextButton, _extends({}, formOptions, {
      handleNext: handleNext,
      nextStep: nextStep,
      nextLabel: next,
      submitLabel: submit
    })), /*#__PURE__*/React.createElement(Button, {
      type: "button",
      variant: "secondary",
      isDisabled: disableBack,
      onClick: handlePrev
    }, back), /*#__PURE__*/React.createElement("div", {
      className: "pf-c-wizard__footer-cancel"
    }, /*#__PURE__*/React.createElement(Button, {
      type: "button",
      variant: "link",
      onClick: formOptions.onCancel
    }, cancel)));
  }));
};

WizardStepButtons.propTypes = {
  disableBack: PropTypes.bool,
  handlePrev: PropTypes.func.isRequired,
  handleNext: PropTypes.func.isRequired,
  nextStep: PropTypes.oneOfType([PropTypes.string, PropTypes.shape({
    when: PropTypes.string.isRequired,
    stepMapper: PropTypes.object.isRequired
  }), PropTypes.func]),
  buttonLabels: PropTypes.shape({
    submit: PropTypes.node.isRequired,
    cancel: PropTypes.node.isRequired,
    back: PropTypes.node.isRequired,
    next: PropTypes.node.isRequired
  }).isRequired,
  buttonsClassName: PropTypes.string,
  buttons: PropTypes.oneOfType([PropTypes.node, PropTypes.func]),
  formOptions: PropTypes.shape({
    getState: PropTypes.func.isRequired,
    onCancel: PropTypes.func.isRequired
  })
};
export default WizardStepButtons;

==> pf4-component-mapper-3.12.0.tgz: package/esm/wizard/wizard-components/step-buttons.js <==
import _extends from "@babel/runtime/helpers/extends";
import React from 'react';
import PropTypes from 'prop-types';
import { Button } from "@patternfly/react-core/dist/esm/components/Button/Button.js";
import selectNext from '@data-driven-forms/common/wizard/select-next';
import FormSpy from "@data-driven-forms/react-form-renderer/form-spy";

var NextButton = function NextButton(_ref) {
  var nextStep = _ref.nextStep,
      valid = _ref.valid,
      handleNext = _ref.handleNext,
      nextLabel = _ref.nextLabel,
      getState = _ref.getState,
      handleSubmit = _ref.handleSubmit,
      submitLabel = _ref.submitLabel,
      conditionalSubmitFlag = _ref.conditionalSubmitFlag;
  var nextResult = nextStep ? selectNext(nextStep, getState) : nextStep;
  var progressNext = nextResult !== conditionalSubmitFlag && nextStep;
  return /*#__PURE__*/React.createElement(Button, {
    variant: "primary",
    type: "button",
    isDisabled: !valid || getState().validating,
    onClick: function onClick() {
      return progressNext ? handleNext(selectNext(nextStep, getState)) : handleSubmit();
    }
  }, progressNext ? nextLabel : submitLabel);
};

NextButton.propTypes = {
  nextStep: PropTypes.oneOfType([PropTypes.string, PropTypes.func, PropTypes.object]),
  handleSubmit: PropTypes.func.isRequired,
  submitLabel: PropTypes.node.isRequired,
  valid: PropTypes.bool,
  handleNext: PropTypes.func.isRequired,
  nextLabel: PropTypes.node.isRequired,
  getState: PropTypes.func.isRequired,
  conditionalSubmitFlag: PropTypes.string.isRequired
};

var WizardStepButtons = function WizardStepButtons(_ref2) {
  var Buttons = _ref2.buttons,
      disableBack = _ref2.disableBack,
      handlePrev = _ref2.handlePrev,
      nextStep = _ref2.nextStep,
      handleNext = _ref2.handleNext,
      buttonsClassName = _ref2.buttonsClassName,
      _ref2$buttonLabels = _ref2.buttonLabels,
      cancel = _ref2$buttonLabels.cancel,
      submit = _ref2$buttonLabels.submit,
      back = _ref2$buttonLabels.back,
      next = _ref2$buttonLabels.next,
      formOptions = _ref2.formOptions,
      conditionalSubmitFlag = _ref2.conditionalSubmitFlag;
  return /*#__PURE__*/React.createElement("footer", {
    className: "pf-c-wizard__footer ".concat(buttonsClassName ? buttonsClassName : '')
  }, Buttons ? /*#__PURE__*/React.createElement(Buttons, {
    disableBack: disableBack,
    handlePrev: handlePrev,
    nextStep: nextStep,
    handleNext: handleNext,
    buttonsClassName: buttonsClassName,
    buttonLabels: {
      cancel: cancel,
      submit: submit,
      back: back,
      next: next
    },
    renderNextButton: function renderNextButton(args) {
      return /*#__PURE__*/React.createElement(NextButton, _extends({}, formOptions, {
        handleNext: handleNext,
        nextStep: nextStep,
        nextLabel: next,
        submitLabel: submit
      }, args));
    },
    selectNext: selectNext
  }) : /*#__PURE__*/React.createElement(FormSpy, null, function () {
    return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(NextButton, _extends({}, formOptions, {
      conditionalSubmitFlag: conditionalSubmitFlag,
      handleNext: handleNext,
      nextStep: nextStep,
      nextLabel: next,
      submitLabel: submit
    })), /*#__PURE__*/React.createElement(Button, {
      type: "button",
      variant: "secondary",
      isDisabled: disableBack,
      onClick: handlePrev
    }, back), /*#__PURE__*/React.createElement("div", {
      className: "pf-c-wizard__footer-cancel"
    }, /*#__PURE__*/React.createElement(Button, {
      type: "button",
      variant: "link",
      onClick: formOptions.onCancel
    }, cancel)));
  }));
};

WizardStepButtons.propTypes = {
  disableBack: PropTypes.bool,
  conditionalSubmitFlag: PropTypes.string.isRequired,
  handlePrev: PropTypes.func.isRequired,
  handleNext: PropTypes.func.isRequired,
  nextStep: PropTypes.oneOfType([PropTypes.string, PropTypes.shape({
    when: PropTypes.string.isRequired,
    stepMapper: PropTypes.object.isRequired
  }), PropTypes.func]),
  buttonLabels: PropTypes.shape({
    submit: PropTypes.node.isRequired,
    cancel: PropTypes.node.isRequired,
    back: PropTypes.node.isRequired,
    next: PropTypes.node.isRequired
  }).isRequired,
  buttonsClassName: PropTypes.string,
  buttons: PropTypes.oneOfType([PropTypes.node, PropTypes.func]),
  formOptions: PropTypes.shape({
    getState: PropTypes.func.isRequired,
    onCancel: PropTypes.func.isRequired
  })
};
export default WizardStepButtons;
